#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gitit
version:              0.16
visibility:           public
id:                   gitit-0.16-4BYus1QDTtO7qzjiTdYkoM
key:                  gitit-0.16-4BYus1QDTtO7qzjiTdYkoM
license:              LicenseRef-GPL
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
synopsis:             Wiki using happstack, git or darcs, and pandoc.
description:
    Gitit is a wiki backed by a git, darcs, or mercurial
    filestore.  Pages and uploaded files can be modified either
    directly via the VCS'\''s command-line tools or through
    the wiki'\''s web interface. Pandoc is used for markup
    processing, so pages may be written in
    (extended) markdown, reStructuredText, LaTeX, HTML,
    or literate Haskell.

    Notable features include

    * plugins: dynamically loaded page
    transformations written in Haskell (see
    "Network.Gitit.Interface")

    * conversion of TeX math to MathML for display in
    web browsers

    * syntax highlighting of source code
    files and code snippets

    * Atom feeds (site-wide and per-page)

    * a library, "Network.Gitit", that makes it simple
    to include a gitit wiki in any happstack application

    For usage information:  @gitit --help@

category:             Network
abi:                  e522c4e578251478d8c0924aaaabeac3
exposed:              True
exposed-modules:
    Network.Gitit Network.Gitit.Authentication
    Network.Gitit.Authentication.Github Network.Gitit.Cache
    Network.Gitit.Compat.Except Network.Gitit.Config
    Network.Gitit.ContentTransformer Network.Gitit.Feed
    Network.Gitit.Framework Network.Gitit.Handlers
    Network.Gitit.Initialize Network.Gitit.Interface
    Network.Gitit.Layout Network.Gitit.Page Network.Gitit.Plugins
    Network.Gitit.Server Network.Gitit.State Network.Gitit.Types
    Network.Gitit.Util Paths_gitit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gitit-0.16
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gitit-0.16
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gitit-0.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/gitit
hs-libraries:         HSgitit-0.16-4BYus1QDTtO7qzjiTdYkoM
depends:
    HStringTemplate-0.8.8-JR7C7BA6XziEBiIvLyw9PC
    HTTP-4000.5.0-24i0sCnOndh6bOgnKr1MTY
    SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg
    aeson-2.2.2.0-C59vZnSjH3DEmVbOnYEZqj base-4.18.2.1
    base64-bytestring-1.2.1.0-LZzfJtlIG52AkUlWG0qoMe
    blaze-html-0.9.2.0-GzsXlvfrcqyCxImJscSKAz bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5
    doctemplates-0.11.0.1-4BXMMGvwEDP1o5BMPJLJ9z
    feed-1.3.2.1-ktwyPvIsw3C4D8ZVFnlhq filepath-1.4.300.1
    filestore-0.6.5.1-GrTXY69WgSvClUk28ep24 ghc-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    happstack-server-7.9.3-6r7IrDBqtcU4JWZqZ8qq1b
    hoauth2-2.14.0-EQMNmqpYoGn8I63NsMyaRi
    hslogger-1.3.2.0-JYhVyo7dnzFAg9NVZZWzq9
    http-client-tls-0.3.6.4-BpM0XRSvwZ99JZv1J5vtXV
    http-conduit-2.3.9.1-9MREEIGDTJE2iYXOHTEmcN
    json-0.11-4EOlV5N1PaF4TrpRwGhy4P mtl-2.3.1
    network-3.1.4.0-FBuTdTHZ29uBPcO3Y238RO
    network-bsd-2.8.1.0-9qLqeYlVUzl3VLScMyoiFo
    network-uri-2.6.4.2-Fs1V3yFgC4iGyoDpGJIE7J
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    old-time-1.1.1.0-Cs8aEqgn6zJ9bpvFdu3ghq
    pandoc-3.6-AEm91vKxfQ9D3hkyZsENl3
    pandoc-types-1.23.1.1-2le9qh5vQuCLiqT4gx4lIM parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.19.0
    random-1.2.1.3-2D6Xw54bvJBUzxlFqHjEz
    recaptcha-0.1.0.4-BgLFF0PbAVuHYS7uZoZeau
    safe-0.3.21-9gbMGq7NJ675hqTemGOkyG
    skylighting-0.14.5-G8KGNDOmouu983nOLub22F
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl syb-0.7.3-11K0viXu9hkJBGIPMEQMvn
    tagsoup-0.14.8-F4Ry8R73HlTBvOvfzZMJjd
    temporary-1.3-BCLEeiJZS9p2VFxBOmtDaG text-2.0.2 time-1.12.2
    uri-bytestring-0.3.3.1-50VincF35teBnkW3InUH7w
    url-2.1.3-FnoMg0Amz5x5iDNEWuwHDq
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    uuid-1.3.16.1-FtFpzG0ItEW5kni5q1Y0lR xhtml-3000.2.2.1
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-conduit-1.9.1.4-HR85KtUhDop5fDlLuGNMPr
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    xss-sanitize-0.3.7.2-FSMfbaO6uIx4GxhVCI53j5
    zlib-0.7.1.0-C72dPpIBAem76SHRIfq7NC

haddock-interfaces:   /usr/share/doc/gitit/html/gitit.haddock
haddock-html:         /usr/share/doc/gitit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

